@@ -1,7 +1,7 @@
 /*
  * Output command-line help to stdout.
  *
- * Copyright 2013 Andrew Wood, distributed under the Artistic License 2.0.
+ * Copyright 2014 Andrew Wood, distributed under the Artistic License 2.0.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -41,6 +41,10 @@ void display_help(void)
 		 N_("show data transfer average rate counter")},
 		{"-b", "--bytes", 0,
 		 N_("show number of bytes transferred")},
+		{"-T", "--buffer-percent", 0,
+		 N_("show percentage of transfer buffer in use")},
+		{"-A", "--last-written", _("NUM"),
+		 N_("show NUM bytes last written")},
 		{"-F", "--format", N_("FORMAT"),
 		 N_("set output format to FORMAT")},
 		{"-n", "--numeric", 0,
@@ -54,6 +58,8 @@ void display_help(void)
 		 N_("set estimated data size to SIZE bytes")},
 		{"-l", "--line-mode", 0,
 		 N_("count lines instead of bytes")},
+		{"-0", "--null", 0,
+		 N_("lines are null-terminated")},
 		{"-i", "--interval", N_("SEC"),
 		 N_("update every SEC seconds")},
 		{"-w", "--width", N_("WIDTH"),
@@ -71,6 +77,8 @@ void display_help(void)
 		 N_("limit transfer to RATE bytes per second")},
 		{"-B", "--buffer-size", N_("BYTES"),
 		 N_("use a buffer size of BYTES")},
+		{"-C", "--no-splice", 0,
+		 N_("never use splice(), always use read/write")},
 		{"-E", "--skip-errors", 0,
 		 N_("skip read errors in input")},
 		{"-S", "--stop-at-size", 0,
@@ -83,6 +91,9 @@ void display_help(void)
 		{"-P", "--pidfile", N_("FILE"),
 		 N_("save process ID in FILE")},
 		{"", 0, 0, 0},
+		{"-d", "--watchfd", N_("PID[:FD]"),
+		 N_("watch file FD opened by process PID")},
+		{"", 0, 0, 0},
 		{"-h", "--help", 0,
 		 N_("show this help and exit")},
 		{"-V", "--version", 0,
